@@ -8,6 +8,11 @@ set -C
 set -u
 # Useful when debugging tests (but autopkgtests should not write to stderr).
 
+# The tests call `dh_gencontrol` and it should not need to
+# chown things. This variable is documented in `rootless-builds.txt`
+# as how to state that the build should be using rootless semantics.
+export DEB_RULES_REQUIRES_ROOT=no
+
 fake_changelog () {
     echo 'foo (1.0-1) unstable; urgency=low
 
@@ -22,8 +27,7 @@ fake_control_header () {
 Section: misc
 Priority: optional
 Maintainer: Test <testing@nowhere>
-Standards-Version: 4.6.2
-Rules-Requires-Root: no
+Standards-Version: 4.7.2
 Build-Depends: debhelper-compat (= 13), $build_depends"
 }
 
